@@ -1,22 +1,29 @@
-from typing import Dict, Sequence
-from abc import ABCMeta
+from typing import Dict, Union
+from abc import ABC, abstractmethod
 from ase import Atoms
-from clease.datastructures import SystemChange
+from clease.datastructures import SystemChanges
+from clease.montecarlo.mc_evaluator import MCEvaluator, construct_evaluator
 
 __all__ = ('BarrierModel', 'BEPBarrier')
 
 
-# pylint: disable=too-few-public-methods
-class BarrierModel(metaclass=ABCMeta):
+class BarrierModel(ABC):
     """
     Base barrier model class
     """
 
-    def __call__(self, atoms: Atoms, system_change: Sequence[SystemChange]) -> float:
-        raise NotImplementedError("__call__ must be implemented in derived classes")
+    def __call__(self, system: Union[Atoms, MCEvaluator], system_changes: SystemChanges) -> float:
+        """Get the height of the barrier"""
+        # Ensure we have a valid evaluator object
+        evaluator = construct_evaluator(system)
+
+        return self.evaluate_barrier(evaluator, system_changes)
+
+    @abstractmethod
+    def evaluate_barrier(self, evaluator: MCEvaluator, system_changes: SystemChanges) -> float:
+        """Evaluate the height of the barrier"""
 
 
-# pylint: disable=too-few-public-methods
 class BEPBarrier(BarrierModel):
     """
     BEP barrier implements the Bell-Evans-Polanyi model. It is a simple barrier
@@ -28,12 +35,12 @@ class BEPBarrier(BarrierModel):
     where E_1 is the total energy of starting configuration and E_2 is the
     total energy of the end configuration. Q_s is a constant that depends
     on the species. If an isolated solute is diffusing in a host material
-    E_1 = E_2. Thus, Q_s represents the barrier of an isolated solute. References
+    E_1 = E_2. Thus, Q_s represents the barrier of an isolated solute. References:
 
-    [1] https://en.wikipedia.org/wiki/Bell%E2%80%93Evans%E2%80%93Polanyi_principle
-    [2] Andersen, M., Panosetti, C. and Reuter, K., 2019.
-        A practical guide to surface kinetic Monte Carlo simulations.
-        Frontiers in chemistry, 7, p.202. DOI: https://doi.org/10.3389/fchem.2019.00202
+    1. The `Bell-Evans-Polanyi`_ principle.
+    2. Andersen, M., Panosetti, C. and Reuter, K., 2019.
+       A practical guide to surface kinetic Monte Carlo simulations.
+       Frontiers in chemistry, 7, p.202. DOI: https://doi.org/10.3389/fchem.2019.00202
 
     :param dilute_barrier: Dictionary representing the dilute barrier for
         each species. Example {'Al': 0.05, 'Mg': 0.03}
@@ -41,16 +48,24 @@ class BEPBarrier(BarrierModel):
         of the transition state along the reaction coordinate. Default is 0.5.
         Note as alpha is the same for all jumps, it must be viewed as
         controlling the average barrier position.
+
+    .. _Bell-Evans-Polanyi:
+        https://en.wikipedia.org/wiki/Bell%E2%80%93Evans%E2%80%93Polanyi_principle>
     """
 
-    def __init__(self, dilute_barrier: Dict[str, float], alpha: float = 0.5):
+    def __init__(
+        self,
+        dilute_barrier: Dict[str, float],
+        alpha: float = 0.5,
+    ):
         super().__init__()
         self.dilute_barrier = dilute_barrier
         self.alpha = alpha
 
-    def __call__(self, atoms: Atoms, system_changes: Sequence[SystemChange]) -> float:
-        E1 = atoms.calc.updater.get_energy()
-        E2 = atoms.calc.get_energy_given_change(system_changes)
+    def evaluate_barrier(self, evaluator: MCEvaluator, system_changes: SystemChanges) -> float:
+        E1 = evaluator.get_energy()
+        # Get the energy given a change, remember to undo the changes again.
+        E2 = evaluator.get_energy_given_change(system_changes)
 
         # Extract the jumping species. The system change should involve
         # a vacancy and another element. Thus, the jumping species is the
