@@ -1,8 +1,9 @@
 """Class containing a manager for setting up concentrations of species."""
 from collections import OrderedDict
+from random import choice
 import numpy as np
-from numpy.random import choice
 from scipy.optimize import minimize
+from clease.jsonio import jsonable
 from clease.tools import (remove_redundant_constraints, remove_redundant_equations)
 
 __all__ = ('Concentration',)
@@ -13,19 +14,18 @@ class IntConversionNotConsistentError(Exception):
     Exception raised if equality constraints are not satisfied when
     converted to integers.
     """
-    pass
 
 
 class InvalidConcentrationError(Exception):
     """Exception raised when no valid concentration could be found."""
-    pass
 
 
 class InvalidConstraintError(Exception):
     """Exception raised when user provides invalid constraints."""
-    pass
 
 
+# pylint: disable=too-many-instance-attributes
+@jsonable('concentration')
 class Concentration:
     """
     Specify concentration ranges of consituting elements for cluster
@@ -49,7 +49,12 @@ class Concentration:
     grouped_basis: list (optional, only used when basis are grouped)
         Indices of basis_elements that are considered to be equivalent when
         specifying concentration (e.g., useful when two basis are shared by
-        the same set of elements and no distinctions are made between them)
+        the same set of elements and no distinctions are made between them).
+        As an example consider a structure with three sublattices A, B and C.
+        If sublattice A and C should be occupied by the same elements and B is
+        occupied by a different set of elements. We can group lattice A and C
+        by passing [(0, 2), (1,)].
+
 
     A_lb: list (optional, only used for linear algebra representation)
         A two-dimention matrix (or nested list) used to specify the lower
@@ -65,6 +70,17 @@ class Concentration:
     b_eq: list (optional, only used for linear algegra representation)
         A list used tp specify the equality condisitons of the concentration
         ranges.
+
+    Example I: Single sublattice
+
+    >>> conc = Concentration(basis_elements=[['Au', 'Cu']])
+
+    Example II: Two sublattices
+    >>> conc = Concentration(basis_elements=[['Au', 'Cu'], ['Au', 'Cu', 'X']])
+
+    Example III: Three sublattices where the first and third are grouped
+    >>> conc = Concentration(basis_elements=[['Au', 'Cu'], ['Au', 'Cu', 'X'], ['Au', 'Cu']],
+    ...                      grouped_basis=[(0, 2), (1,)])
     """
 
     def __init__(self,
@@ -88,7 +104,7 @@ class Concentration:
         self.num_concs = len([x for sub in self.basis_elements for x in sub])
         self.fixed_element_constraint_added = False
 
-        if A_lb:
+        if A_lb is not None:
             self.A_lb, self.b_lb = remove_redundant_constraints(np.array(A_lb), np.array(b_lb))
         else:
             self.A_lb = np.empty((0, self.num_concs))
@@ -113,7 +129,7 @@ class Concentration:
             start_col += len(basis)
             self.b_eq[i] = 1
 
-        self._linked_basis = [i for i in range(len(self.basis_elements))]
+        self._linked_basis = list(range(len(self.basis_elements)))
         if num_usr_eq > 0:
             self.add_usr_defined_eq_constraints(A_eq, b_eq)
         self._get_interbasis_relations()
@@ -135,23 +151,23 @@ class Concentration:
             gr_basis_elements.append(self.orig_basis_elements[group[0]])
         return gr_basis_elements
 
-    def to_dict(self):
+    def todict(self) -> dict:
         """Return neescary information to store as JSON."""
         data = {
-            "A_eq": self.A_eq.tolist(),
-            "b_eq": self.b_eq.tolist(),
-            "A_lb": self.A_lb.tolist(),
-            "b_lb": self.b_lb.tolist(),
+            "A_eq": self.A_eq,
+            "b_eq": self.b_eq,
+            "A_lb": self.A_lb,
+            "b_lb": self.b_lb,
             "basis_elements": self.orig_basis_elements,
         }
         if self.grouped_basis is not None:
             data["grouped_basis"] = self.grouped_basis
         return data
 
-    @staticmethod
-    def from_dict(data):
+    @classmethod
+    def from_dict(cls, data):
         """Initialize data from dictionary."""
-        return Concentration(**data)
+        return cls(**data)
 
     def is_valid_conc(self, conc):
         """Check if the concentration is valid."""
@@ -238,8 +254,8 @@ class Concentration:
 
         self.A_lb = np.vstack((self.A_lb, A_lb))
         self.b_lb = np.append(self.b_lb, b_lb)
-        self.A_lb, self.b_lb = remove_redundant_constraints(
-            self.A_lb, self.b_lb, self.A_eq, self.b_eq)
+        self.A_lb, self.b_lb = remove_redundant_constraints(self.A_lb, self.b_lb, self.A_eq,
+                                                            self.b_eq)
         self._get_interbasis_relations_for_given_matrix(self.A_lb)
 
     def set_conc_ranges(self, ranges):
@@ -284,6 +300,7 @@ class Concentration:
 
     def _get_integers(self, string, variable_range=None):
         """Extract all the integers from a string."""
+        # pylint: disable=no-self-use,too-many-branches
         if variable_range is None:
             variable_symbols = []
         else:
@@ -295,7 +312,7 @@ class Concentration:
         active_sign = 1
         while current_indx < len(string):
             connected_to_symbol = False
-            if string[current_indx] in signs.keys():
+            if string[current_indx] in signs:
                 active_sign = signs[string[current_indx]]
             elif string[current_indx] == "<":
                 active_sign = 1
@@ -335,7 +352,7 @@ class Concentration:
         # Ensure valid chemical formula
         for _, value in sum_of_variable_coeff.items():
             if value != 0:
-                raise ValueError(f"Invalid formula! {string} " f"{sum_of_variable_coeff}")
+                raise ValueError(f"Invalid formula! {string} {sum_of_variable_coeff}")
         return integers
 
     def _num_atoms_in_basis(self, formulas, variable_range):
@@ -363,6 +380,7 @@ class Concentration:
             key is a string, and the value should be int or float
             e.g., {"x": (0, 2), "y": (0, 0.7)}, {'x': (0., 1.)}
         """
+        # pylint: disable=too-many-branches
         if formulas is None or variable_range is None:
             raise InvalidConstraintError("formula and variable range has to" " be provided!")
 
@@ -439,8 +457,9 @@ class Concentration:
         self._f_u_neq(variable_range, reference_elements, formulas)
 
     def _num_elements_with_var(self, variable_range, element_conc):
-        # count how many elements have their concentration specified with
-        # the passed variable.
+        """count how many elements have their concentration specified with
+        the passed variable."""
+        # pylint: disable=no-self-use
         num_elements_with_variable = {k: 0 for k in variable_range.keys()}
         for var in variable_range.keys():
             for basis_elem in element_conc:
@@ -481,6 +500,7 @@ class Concentration:
 
     def _reference_elements(self, element_conc, variables):
         """Return the reference element for each variable."""
+        # pylint: disable=no-self-use
         # reference element is the one that has its concentration specified
         # with a clean representation (e.g., <x> or <y>)
         ref_elem = {}
@@ -488,13 +508,14 @@ class Concentration:
             col = 0
             for basis_elem in element_conc:
                 for k, v in basis_elem.items():
-                    if v == variable and v not in ref_elem.keys():
+                    if v == variable and v not in ref_elem:
                         ref_elem[variable] = {"symbol": k, "col": col}
                     col += 1
         return ref_elem
 
     def _get_basis_containg_variable(self, formulas, variable_symbol):
         """Return index of the basis containing the passed varyable symbol."""
+        # pylint: disable=no-self-use
         for basis, formula in enumerate(formulas):
             if variable_symbol in formula:
                 return basis
@@ -524,6 +545,7 @@ class Concentration:
         string: str
             string of the following form 3x, 10y, 3z etc.
         """
+        # pylint: disable=no-self-use
         if not string[0].isdigit():
             return 1
 
@@ -551,7 +573,7 @@ class Concentration:
                     elements.append(split2[1])
                     math.append(split2[0])
             if elements != self.basis_elements[basis_num]:
-                raise ValueError("elements in 'formulas' and 'basis_elements' " "should match.")
+                raise ValueError("elements in 'formulas' and 'basis_elements' should match.")
             element_variable.append(OrderedDict(zip(elements, math)))
         return element_variable
 
@@ -664,7 +686,7 @@ class Concentration:
         return x
 
     def _get_interbasis_relations(self):
-        self._linked_basis = [i for i in range(len(self.basis_elements))]
+        self._linked_basis = list(range(len(self.basis_elements)))
         self._get_interbasis_relations_for_given_matrix(self.A_eq)
         self._get_interbasis_relations_for_given_matrix(self.A_lb)
 
@@ -910,6 +932,7 @@ def equality_constraint(x, vec, rhs):
 
 def eq_jac(x, vec, rhs):
     """Jacobian of the equalitu constraint equation."""
+    # pylint: disable=unused-argument
     return vec
 
 
@@ -921,4 +944,5 @@ def inequality_constraint(x, vec, rhs):
 
 def ineq_jac(x, vec, rhs):
     """Jacobian of the inequality constraint equations."""
+    # pylint: disable=unused-argument
     return vec
